@@ -21,7 +21,12 @@ def runcmd(cmd):
     """ Execute a command using the subprocess module """
 
     if win32:
-        raise NotImplementedError('No windows support so far')
+        from subprocess import Popen
+
+        cmd = cmd.replace('\\', '/')
+        s = Popen(cmd, shell=False)
+        s.wait()
+        return 0, ''
 
     else:      
 
